==============
INSPIRE-DoJSON
==============

.. image:: https://coveralls.io/repos/github/inspirehep/inspire-dojson/badge.svg?branch=master
    :target: https://coveralls.io/github/inspirehep/inspire-dojson?branch=master

.. image:: https://travis-ci.org/inspirehep/inspire-dojson.svg?branch=master
    :target: https://travis-ci.org/inspirehep/inspire-dojson

INSPIRE-specific rules to transform from XML to JSON and back.
